@@ -1,6 +1,8 @@
 /*
  * Copyright © 2011 Canonical Ltd.
  *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
@@ -72,7 +74,7 @@ org_gtk_Menus_get_interface (void)
                                            "  </interface>"
                                            "</node>", &error);
       if (info == NULL)
-        g_error ("%s\n", error->message);
+        g_error ("%s", error->message);
       interface_info = g_dbus_node_info_lookup_interface (info, "org.gtk.Menus");
       g_assert (interface_info != NULL);
       g_dbus_interface_info_ref (interface_info);
@@ -525,7 +527,9 @@ g_menu_exporter_remote_free (gpointer data)
       g_menu_exporter_group_unsubscribe (group, GPOINTER_TO_INT (val));
     }
 
-  g_bus_unwatch_name (remote->watch_id);
+  if (remote->watch_id > 0)
+    g_bus_unwatch_name (remote->watch_id);
+
   g_hash_table_unref (remote->watches);
 
   g_slice_free (GMenuExporterRemote, remote);
@@ -556,6 +560,7 @@ struct _GMenuExporter
   guint next_group_id;
 
   GMenuExporterMenu *root;
+  GMenuExporterRemote *peer_remote;
   GHashTable *remotes;
 };
 
@@ -582,16 +587,25 @@ g_menu_exporter_subscribe (GMenuExporter *exporter,
   GVariantIter iter;
   guint32 id;
 
-  remote = g_hash_table_lookup (exporter->remotes, sender);
+  if (sender != NULL)
+    remote = g_hash_table_lookup (exporter->remotes, sender);
+  else
+    remote = exporter->peer_remote;
 
   if (remote == NULL)
     {
-      guint watch_id;
+      if (sender != NULL)
+        {
+          guint watch_id;
 
-      watch_id = g_bus_watch_name_on_connection (exporter->connection, sender, G_BUS_NAME_WATCHER_FLAGS_NONE,
-                                                 NULL, g_menu_exporter_name_vanished, exporter, NULL);
-      remote = g_menu_exporter_remote_new (exporter, watch_id);
-      g_hash_table_insert (exporter->remotes, g_strdup (sender), remote);
+          watch_id = g_bus_watch_name_on_connection (exporter->connection, sender, G_BUS_NAME_WATCHER_FLAGS_NONE,
+                                                     NULL, g_menu_exporter_name_vanished, exporter, NULL);
+          remote = g_menu_exporter_remote_new (exporter, watch_id);
+          g_hash_table_insert (exporter->remotes, g_strdup (sender), remote);
+        }
+      else
+        remote = exporter->peer_remote =
+          g_menu_exporter_remote_new (exporter, 0);
     }
 
   g_variant_builder_init (&builder, G_VARIANT_TYPE ("(a(uuaa{sv}))"));
@@ -616,7 +630,10 @@ g_menu_exporter_unsubscribe (GMenuExporter *exporter,
   GVariantIter iter;
   guint32 id;
 
-  remote = g_hash_table_lookup (exporter->remotes, sender);
+  if (sender != NULL)
+    remote = g_hash_table_lookup (exporter->remotes, sender);
+  else
+    remote = exporter->peer_remote;
 
   if (remote == NULL)
     return;
@@ -626,7 +643,12 @@ g_menu_exporter_unsubscribe (GMenuExporter *exporter,
     g_menu_exporter_remote_unsubscribe (remote, id);
 
   if (!g_menu_exporter_remote_has_subscriptions (remote))
-    g_hash_table_remove (exporter->remotes, sender);
+    {
+      if (sender != NULL)
+        g_hash_table_remove (exporter->remotes, sender);
+      else
+        g_clear_pointer (&exporter->peer_remote, g_menu_exporter_remote_free);
+    }
 }
 
 static void
@@ -691,6 +713,7 @@ g_menu_exporter_free (gpointer user_data)
   GMenuExporter *exporter = user_data;
 
   g_menu_exporter_menu_free (exporter->root);
+  g_clear_pointer (&exporter->peer_remote, g_menu_exporter_remote_free);
   g_hash_table_unref (exporter->remotes);
   g_hash_table_unref (exporter->groups);
   g_object_unref (exporter->connection);
@@ -762,7 +785,7 @@ g_dbus_connection_export_menu_model (GDBusConnection  *connection,
                                      GError          **error)
 {
   const GDBusInterfaceVTable vtable = {
-    g_menu_exporter_method_call,
+    g_menu_exporter_method_call, NULL, NULL, { 0 }
   };
   GMenuExporter *exporter;
   guint id;
